// ignore_for_file: public_member_api_docs

import 'package:fl_chart/fl_chart.dart';
import 'package:mobx/mobx.dart';

part 'streams.g.dart';

class Streams = StreamsBase with _$Streams;

abstract class StreamsBase with Store {
  /// [rawStreamEcg] is a raw ecg stream from device.
  @observable
  Stream<List<int>>? rawStreamEcg;

  /// [decompressedStreamEcg] is a decompressed ecg stream.
  /// Where there is no compression, it is equal to [rawStreamEcg].
  ///
  /// The decompression codec is LZMA algorithm.
  @observable
  Stream<List<int>>? decompressedStreamEcg;

  /// [recentStreamEcg] is a recent stream,
  /// which is converted into double-typed values.
  @observable
  Stream<List<double>>? recentStreamEcg;

  /// [bufferedStreamEcg] is a buffered stream for ecg measurement,
  /// which has a flexible buffer whose size is controlled by [Ecg].
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<List<double>>? bufferedStreamEcg;

  /// [bufferedPlotStreamEcg] is a buffered stream for plotting ecg signals,
  /// which has a flexible buffer whose size is controlled by [Ecg].
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<List<FlSpot>>? bufferedPlotStreamEcg;

  /// [rawStreamOxi] is a raw ecg stream from device.
  @observable
  Stream<List<int>>? rawStreamOxi;

  /// [decompressedStreamOxi] is a decompressed pulse oxi stream.
  /// Where there is no compression, it is equal to [rawStreamOxi].
  ///
  /// The decompression codec is LZMA algorithm.
  @observable
  Stream<List<int>>? decompressedStreamOxi;

  /// [recentStreamOxi] is a recent stream for pulse oxi measurement,
  /// which is converted into double-typed values.
  @observable
  Stream<List<double>>? recentStreamOxi;

  /// [bufferedStreamOxi] is a buffered stream for pulse oxi measurement.
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<List<List<double>>>? bufferedStreamOxi;

  /// [bufferedPlotStreamOxi] is a buffered stream for plotting pulse oxi.
  ///
  /// By default, it contains 30~40 seconds result.
  @observable
  Stream<List<List<FlSpot>>>? bufferedPlotStreamOxi;
}
